[pkg-fso-commits] [SCM] FSO frameworkd Debian packaging branch, master, updated. milestone4-368-g700ab82

Michael 'Mickey' Lauer mickey at vanille-media.de
Mon Feb 2 18:51:57 UTC 2009


The following commit has been merged in the master branch:
commit 08fad37bcffe5a3974301458732c728c0393506e
Author: Michael 'Mickey' Lauer <mickey at vanille-media.de>
Date:   Thu Jan 15 18:52:09 2009 +0100

    ogsmd: const: add GSM number types seen "in the field"

diff --git a/framework/subsystems/ogsmd/gsm/const.py b/framework/subsystems/ogsmd/gsm/const.py
index 356b23d..8a17203 100644
--- a/framework/subsystems/ogsmd/gsm/const.py
+++ b/framework/subsystems/ogsmd/gsm/const.py
@@ -13,13 +13,16 @@ Module: const
 GSM constants, strings, formats, parse patterns, timeouts, you name it.
 """
 
+__version__ = "0.8.0"
+MODULE_NAME = "ogsmd.const"
+
 from framework import config
 from ogsmd.helpers import BiDict
 
 import re, string, os.path
 
 import logging
-logger = logging.getLogger( "ogsmd" )
+logger = logging.getLogger( MODULE_NAME )
 
 #=========================================================================#
 # format patterns
@@ -1046,9 +1049,9 @@ def phonebookTupleToNumber( nstring, ntype ):
     Returns a full number depending on a number string and a number type.
     """
 
     # FIXME unknown types seen so far: 185, 208, 255
     # type128: network TR TCELL appears to use it as 4 digit intracompany calls
-    if ntype not in ( 129, 145 ):
+    if ntype not in ( 128, 129, 145, 160, 185, 208, 255 ):
         logger.warning( "Out-of-spec GSM number type seen: %s. Please report." % ntype )
 
     if ntype == 145: # should not include '+' then, but on some modems, it does
@@ -1046,9 +1049,9 @@ def phonebookTupleToNumber( nstring, ntype ):
     """
 
-    # FIXME unknown types seen so far: 185, 208, 255
+    # FIXME unknown types seen so far: 160, 185, 208, 255
     # type128: network TR TCELL appears to use it as 4 digit intracompany calls

-- 
FSO frameworkd Debian packaging



More information about the pkg-fso-commits mailing list